
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['downtime_jail_duration', 'min_signed_per_window', 'signed_blocks_window', 'slash_fraction_double_sign', 'slash_fraction_downtime']
    DOWNTIME_JAIL_DURATION_FIELD_NUMBER: _ClassVar[int]
    MIN_SIGNED_PER_WINDOW_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BLOCKS_WINDOW_FIELD_NUMBER: _ClassVar[int]
    SLASH_FRACTION_DOUBLE_SIGN_FIELD_NUMBER: _ClassVar[int]
    SLASH_FRACTION_DOWNTIME_FIELD_NUMBER: _ClassVar[int]
    downtime_jail_duration: _duration_pb2.Duration
    min_signed_per_window: bytes
    signed_blocks_window: int
    slash_fraction_double_sign: bytes
    slash_fraction_downtime: bytes

    def __init__(self, signed_blocks_window: _Optional[int]=..., min_signed_per_window: _Optional[bytes]=..., downtime_jail_duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., slash_fraction_double_sign: _Optional[bytes]=..., slash_fraction_downtime: _Optional[bytes]=...) -> None:
        ...

class ValidatorSigningInfo(_message.Message):
    __slots__ = ['address', 'index_offset', 'jailed_until', 'missed_blocks_counter', 'start_height', 'tombstoned']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    INDEX_OFFSET_FIELD_NUMBER: _ClassVar[int]
    JAILED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    MISSED_BLOCKS_COUNTER_FIELD_NUMBER: _ClassVar[int]
    START_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TOMBSTONED_FIELD_NUMBER: _ClassVar[int]
    address: str
    index_offset: int
    jailed_until: _timestamp_pb2.Timestamp
    missed_blocks_counter: int
    start_height: int
    tombstoned: bool

    def __init__(self, address: _Optional[str]=..., start_height: _Optional[int]=..., index_offset: _Optional[int]=..., jailed_until: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., tombstoned: bool=..., missed_blocks_counter: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/mempool/types.proto\x12\x12tendermint.mempool"\x12\n\x03Txs\x12\x0b\n\x03txs\x18\x01 \x03(\x0c"8\n\x07Message\x12&\n\x03txs\x18\x01 \x01(\x0b2\x17.tendermint.mempool.TxsH\x00B\x05\n\x03sumB;Z9github.com/tendermint/tendermint/proto/tendermint/mempoolb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.mempool.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/mempool'
    _TXS._serialized_start = 54
    _TXS._serialized_end = 72
    _MESSAGE._serialized_start = 74
    _MESSAGE._serialized_end = 130




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/vesting/v1beta1/tx.proto\x12\x16cosmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x8e\x02\n\x17MsgCreateVestingAccount\x12-\n\x0cfrom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"from_address"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"to_address"\x12[\n\x06amount\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12%\n\x08end_time\x18\x04 \x01(\x03B\x13\xf2\xde\x1f\x0fyaml:"end_time"\x12\x0f\n\x07delayed\x18\x05 \x01(\x08:\x04\xe8\xa0\x1f\x01"!\n\x1fMsgCreateVestingAccountResponse2\x88\x01\n\x03Msg\x12\x80\x01\n\x14CreateVestingAccount\x12/.cosmos.vesting.v1beta1.MsgCreateVestingAccount\x1a7.cosmos.vesting.v1beta1.MsgCreateVestingAccountResponseB3Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
    _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._options = None
    _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"from_address"'
    _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._options = None
    _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._serialized_options = b'\xf2\xde\x1f\x11yaml:"to_address"'
    _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._options = None
    _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGCREATEVESTINGACCOUNT.fields_by_name['end_time']._options = None
    _MSGCREATEVESTINGACCOUNT.fields_by_name['end_time']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"end_time"'
    _MSGCREATEVESTINGACCOUNT._options = None
    _MSGCREATEVESTINGACCOUNT._serialized_options = b'\xe8\xa0\x1f\x01'
    _MSGCREATEVESTINGACCOUNT._serialized_start = 114
    _MSGCREATEVESTINGACCOUNT._serialized_end = 384
    _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_start = 386
    _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_end = 419
    _MSG._serialized_start = 422
    _MSG._serialized_end = 558




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.mint.v1beta1 import mint_pb2 as cosmos_dot_mint_dot_v1beta1_dot_mint__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/mint/v1beta1/genesis.proto\x12\x13cosmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/mint/v1beta1/mint.proto"t\n\x0cGenesisState\x121\n\x06minter\x18\x01 \x01(\x0b2\x1b.cosmos.mint.v1beta1.MinterB\x04\xc8\xde\x1f\x00\x121\n\x06params\x18\x02 \x01(\x0b2\x1b.cosmos.mint.v1beta1.ParamsB\x04\xc8\xde\x1f\x00B+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
    _GENESISSTATE.fields_by_name['minter']._options = None
    _GENESISSTATE.fields_by_name['minter']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 112
    _GENESISSTATE._serialized_end = 228




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/upgrade/v1beta1/query.proto\x12\x16cosmos.upgrade.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto"\x19\n\x17QueryCurrentPlanRequest"F\n\x18QueryCurrentPlanResponse\x12*\n\x04plan\x18\x01 \x01(\x0b2\x1c.cosmos.upgrade.v1beta1.Plan"\'\n\x17QueryAppliedPlanRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"*\n\x18QueryAppliedPlanResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03"=\n"QueryUpgradedConsensusStateRequest\x12\x13\n\x0blast_height\x18\x01 \x01(\x03:\x02\x18\x01"Q\n#QueryUpgradedConsensusStateResponse\x12 \n\x18upgraded_consensus_state\x18\x02 \x01(\x0c:\x02\x18\x01J\x04\x08\x01\x10\x02"1\n\x1aQueryModuleVersionsRequest\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t"]\n\x1bQueryModuleVersionsResponse\x12>\n\x0fmodule_versions\x18\x01 \x03(\x0b2%.cosmos.upgrade.v1beta1.ModuleVersion2\xdc\x05\n\x05Query\x12\x9e\x01\n\x0bCurrentPlan\x12/.cosmos.upgrade.v1beta1.QueryCurrentPlanRequest\x1a0.cosmos.upgrade.v1beta1.QueryCurrentPlanResponse",\x82\xd3\xe4\x93\x02&\x12$/cosmos/upgrade/v1beta1/current_plan\x12\xa5\x01\n\x0bAppliedPlan\x12/.cosmos.upgrade.v1beta1.QueryAppliedPlanRequest\x1a0.cosmos.upgrade.v1beta1.QueryAppliedPlanResponse"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/upgrade/v1beta1/applied_plan/{name}\x12\xdc\x01\n\x16UpgradedConsensusState\x12:.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateRequest\x1a;.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateResponse"I\x88\x02\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}\x12\xaa\x01\n\x0eModuleVersions\x122.cosmos.upgrade.v1beta1.QueryModuleVersionsRequest\x1a3.cosmos.upgrade.v1beta1.QueryModuleVersionsResponse"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/upgrade/v1beta1/module_versionsB.Z,github.com/cosmos/cosmos-sdk/x/upgrade/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/upgrade/types'
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._options = None
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_options = b'\x18\x01'
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._options = None
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_options = b'\x18\x01'
    _QUERY.methods_by_name['CurrentPlan']._options = None
    _QUERY.methods_by_name['CurrentPlan']._serialized_options = b'\x82\xd3\xe4\x93\x02&\x12$/cosmos/upgrade/v1beta1/current_plan'
    _QUERY.methods_by_name['AppliedPlan']._options = None
    _QUERY.methods_by_name['AppliedPlan']._serialized_options = b'\x82\xd3\xe4\x93\x02-\x12+/cosmos/upgrade/v1beta1/applied_plan/{name}'
    _QUERY.methods_by_name['UpgradedConsensusState']._options = None
    _QUERY.methods_by_name['UpgradedConsensusState']._serialized_options = b'\x88\x02\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}'
    _QUERY.methods_by_name['ModuleVersions']._options = None
    _QUERY.methods_by_name['ModuleVersions']._serialized_options = b"\x82\xd3\xe4\x93\x02)\x12'/cosmos/upgrade/v1beta1/module_versions"
    _QUERYCURRENTPLANREQUEST._serialized_start = 157
    _QUERYCURRENTPLANREQUEST._serialized_end = 182
    _QUERYCURRENTPLANRESPONSE._serialized_start = 184
    _QUERYCURRENTPLANRESPONSE._serialized_end = 254
    _QUERYAPPLIEDPLANREQUEST._serialized_start = 256
    _QUERYAPPLIEDPLANREQUEST._serialized_end = 295
    _QUERYAPPLIEDPLANRESPONSE._serialized_start = 297
    _QUERYAPPLIEDPLANRESPONSE._serialized_end = 339
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_start = 341
    _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_end = 402
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_start = 404
    _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_end = 485
    _QUERYMODULEVERSIONSREQUEST._serialized_start = 487
    _QUERYMODULEVERSIONSREQUEST._serialized_end = 536
    _QUERYMODULEVERSIONSRESPONSE._serialized_start = 538
    _QUERYMODULEVERSIONSRESPONSE._serialized_end = 631
    _QUERY._serialized_start = 634
    _QUERY._serialized_end = 1366




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/authz.proto\x12\x14cosmos.authz.v1beta1\x1a\x19cosmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto"6\n\x14GenericAuthorization\x12\x0b\n\x03msg\x18\x01 \x01(\t:\x11\xca\xb4-\rAuthorization"\x81\x01\n\x05Grant\x12>\n\rauthorization\x18\x01 \x01(\x0b2\x14.google.protobuf.AnyB\x11\xca\xb4-\rAuthorization\x128\n\nexpiration\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00"\xb0\x01\n\x12GrantAuthorization\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12>\n\rauthorization\x18\x03 \x01(\x0b2\x14.google.protobuf.AnyB\x11\xca\xb4-\rAuthorization\x128\n\nexpiration\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01B*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.authz_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00'
    _GENERICAUTHORIZATION._options = None
    _GENERICAUTHORIZATION._serialized_options = b'\xca\xb4-\rAuthorization'
    _GRANT.fields_by_name['authorization']._options = None
    _GRANT.fields_by_name['authorization']._serialized_options = b'\xca\xb4-\rAuthorization'
    _GRANT.fields_by_name['expiration']._options = None
    _GRANT.fields_by_name['expiration']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00'
    _GRANTAUTHORIZATION.fields_by_name['authorization']._options = None
    _GRANTAUTHORIZATION.fields_by_name['authorization']._serialized_options = b'\xca\xb4-\rAuthorization'
    _GRANTAUTHORIZATION.fields_by_name['expiration']._options = None
    _GRANTAUTHORIZATION.fields_by_name['expiration']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _GENERICAUTHORIZATION._serialized_start = 167
    _GENERICAUTHORIZATION._serialized_end = 221
    _GRANT._serialized_start = 224
    _GRANT._serialized_end = 353
    _GRANTAUTHORIZATION._serialized_start = 356
    _GRANTAUTHORIZATION._serialized_end = 532




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.tx.signing.v1beta1 import signing_pb2 as cosmos_dot_tx_dot_signing_dot_v1beta1_dot_signing__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1acosmos/tx/v1beta1/tx.proto\x12\x11cosmos.tx.v1beta1\x1a\x14gogoproto/gogo.proto\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\'cosmos/tx/signing/v1beta1/signing.proto\x1a\x19google/protobuf/any.proto"q\n\x02Tx\x12\'\n\x04body\x18\x01 \x01(\x0b2\x19.cosmos.tx.v1beta1.TxBody\x12.\n\tauth_info\x18\x02 \x01(\x0b2\x1b.cosmos.tx.v1beta1.AuthInfo\x12\x12\n\nsignatures\x18\x03 \x03(\x0c"H\n\x05TxRaw\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0fauth_info_bytes\x18\x02 \x01(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c"`\n\x07SignDoc\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0fauth_info_bytes\x18\x02 \x01(\x0c\x12\x10\n\x08chain_id\x18\x03 \x01(\t\x12\x16\n\x0eaccount_number\x18\x04 \x01(\x04"\xc7\x01\n\x06TxBody\x12&\n\x08messages\x18\x01 \x03(\x0b2\x14.google.protobuf.Any\x12\x0c\n\x04memo\x18\x02 \x01(\t\x12\x16\n\x0etimeout_height\x18\x03 \x01(\x04\x120\n\x11extension_options\x18\xff\x07 \x03(\x0b2\x14.google.protobuf.Any\x12=\n\x1enon_critical_extension_options\x18\xff\x0f \x03(\x0b2\x14.google.protobuf.Any"d\n\x08AuthInfo\x123\n\x0csigner_infos\x18\x01 \x03(\x0b2\x1d.cosmos.tx.v1beta1.SignerInfo\x12#\n\x03fee\x18\x02 \x01(\x0b2\x16.cosmos.tx.v1beta1.Fee"x\n\nSignerInfo\x12(\n\npublic_key\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12.\n\tmode_info\x18\x02 \x01(\x0b2\x1b.cosmos.tx.v1beta1.ModeInfo\x12\x10\n\x08sequence\x18\x03 \x01(\x04"\xb5\x02\n\x08ModeInfo\x124\n\x06single\x18\x01 \x01(\x0b2".cosmos.tx.v1beta1.ModeInfo.SingleH\x00\x122\n\x05multi\x18\x02 \x01(\x0b2!.cosmos.tx.v1beta1.ModeInfo.MultiH\x00\x1a;\n\x06Single\x121\n\x04mode\x18\x01 \x01(\x0e2#.cosmos.tx.signing.v1beta1.SignMode\x1a{\n\x05Multi\x12A\n\x08bitarray\x18\x01 \x01(\x0b2/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12/\n\nmode_infos\x18\x02 \x03(\x0b2\x1b.cosmos.tx.v1beta1.ModeInfoB\x05\n\x03sum"\x95\x01\n\x03Fee\x12[\n\x06amount\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\r\n\x05payer\x18\x03 \x01(\t\x12\x0f\n\x07granter\x18\x04 \x01(\tB\'Z%github.com/cosmos/cosmos-sdk/types/txb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx'
    _FEE.fields_by_name['amount']._options = None
    _FEE.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _TX._serialized_start = 218
    _TX._serialized_end = 331
    _TXRAW._serialized_start = 333
    _TXRAW._serialized_end = 405
    _SIGNDOC._serialized_start = 407
    _SIGNDOC._serialized_end = 503
    _TXBODY._serialized_start = 506
    _TXBODY._serialized_end = 705
    _AUTHINFO._serialized_start = 707
    _AUTHINFO._serialized_end = 807
    _SIGNERINFO._serialized_start = 809
    _SIGNERINFO._serialized_end = 929
    _MODEINFO._serialized_start = 932
    _MODEINFO._serialized_end = 1241
    _MODEINFO_SINGLE._serialized_start = 1050
    _MODEINFO_SINGLE._serialized_end = 1109
    _MODEINFO_MULTI._serialized_start = 1111
    _MODEINFO_MULTI._serialized_end = 1234
    _FEE._serialized_start = 1244
    _FEE._serialized_end = 1393




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tendermint/blockchain/types.proto\x12\x15tendermint.blockchain\x1a\x1ctendermint/types/block.proto"\x1e\n\x0cBlockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03"7\n\rBlockResponse\x12&\n\x05block\x18\x01 \x01(\x0b2\x17.tendermint.types.Block"\x0f\n\rStatusRequest".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04base\x18\x02 \x01(\x03"\xd5\x02\n\x07Message\x12<\n\rblock_request\x18\x01 \x01(\x0b2#.tendermint.blockchain.BlockRequestH\x00\x12C\n\x11no_block_response\x18\x02 \x01(\x0b2&.tendermint.blockchain.NoBlockResponseH\x00\x12>\n\x0eblock_response\x18\x03 \x01(\x0b2$.tendermint.blockchain.BlockResponseH\x00\x12>\n\x0estatus_request\x18\x04 \x01(\x0b2$.tendermint.blockchain.StatusRequestH\x00\x12@\n\x0fstatus_response\x18\x05 \x01(\x0b2%.tendermint.blockchain.StatusResponseH\x00B\x05\n\x03sumB>Z<github.com/tendermint/tendermint/proto/tendermint/blockchainb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.blockchain.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z<github.com/tendermint/tendermint/proto/tendermint/blockchain'
    _BLOCKREQUEST._serialized_start = 90
    _BLOCKREQUEST._serialized_end = 120
    _NOBLOCKRESPONSE._serialized_start = 122
    _NOBLOCKRESPONSE._serialized_end = 155
    _BLOCKRESPONSE._serialized_start = 157
    _BLOCKRESPONSE._serialized_end = 212
    _STATUSREQUEST._serialized_start = 214
    _STATUSREQUEST._serialized_end = 229
    _STATUSRESPONSE._serialized_start = 231
    _STATUSRESPONSE._serialized_end = 277
    _MESSAGE._serialized_start = 280
    _MESSAGE._serialized_end = 621




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/base/kv/v1beta1/kv.proto\x12\x16cosmos.base.kv.v1beta1\x1a\x14gogoproto/gogo.proto":\n\x05Pairs\x121\n\x05pairs\x18\x01 \x03(\x0b2\x1c.cosmos.base.kv.v1beta1.PairB\x04\xc8\xde\x1f\x00""\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0cB\'Z%github.com/cosmos/cosmos-sdk/types/kvb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.kv.v1beta1.kv_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/kv'
    _PAIRS.fields_by_name['pairs']._options = None
    _PAIRS.fields_by_name['pairs']._serialized_options = b'\xc8\xde\x1f\x00'
    _PAIRS._serialized_start = 81
    _PAIRS._serialized_end = 139
    _PAIR._serialized_start = 141
    _PAIR._serialized_end = 175




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15google/api/http.proto\x12\ngoogle.api"T\n\x04Http\x12#\n\x05rules\x18\x01 \x03(\x0b2\x14.google.api.HttpRule\x12\'\n\x1ffully_decode_reserved_expansion\x18\x02 \x01(\x08"\x81\x02\n\x08HttpRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\r\n\x03get\x18\x02 \x01(\tH\x00\x12\r\n\x03put\x18\x03 \x01(\tH\x00\x12\x0e\n\x04post\x18\x04 \x01(\tH\x00\x12\x10\n\x06delete\x18\x05 \x01(\tH\x00\x12\x0f\n\x05patch\x18\x06 \x01(\tH\x00\x12/\n\x06custom\x18\x08 \x01(\x0b2\x1d.google.api.CustomHttpPatternH\x00\x12\x0c\n\x04body\x18\x07 \x01(\t\x12\x15\n\rresponse_body\x18\x0c \x01(\t\x121\n\x13additional_bindings\x18\x0b \x03(\x0b2\x14.google.api.HttpRuleB\t\n\x07pattern"/\n\x11CustomHttpPattern\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\tBj\n\x0ecom.google.apiB\tHttpProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.http_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x0ecom.google.apiB\tHttpProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xf8\x01\x01\xa2\x02\x04GAPI'
    _HTTP._serialized_start = 37
    _HTTP._serialized_end = 121
    _HTTPRULE._serialized_start = 124
    _HTTPRULE._serialized_end = 381
    _CUSTOMHTTPPATTERN._serialized_start = 383
    _CUSTOMHTTPPATTERN._serialized_end = 430




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from sentinel.subscription.v2 import allocation_pb2 as _allocation_pb2
from sentinel.subscription.v2 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['params', 'subscriptions']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    subscriptions: _containers.RepeatedCompositeFieldContainer[GenesisSubscription]

    def __init__(self, subscriptions: _Optional[_Iterable[_Union[(GenesisSubscription, _Mapping)]]]=..., params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...

class GenesisSubscription(_message.Message):
    __slots__ = ['allocations', 'subscription']
    ALLOCATIONS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    allocations: _containers.RepeatedCompositeFieldContainer[_allocation_pb2.Allocation]
    subscription: _any_pb2.Any

    def __init__(self, subscription: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., allocations: _Optional[_Iterable[_Union[(_allocation_pb2.Allocation, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/genesis.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto"\xef\x04\n\x0cGenesisState\x12S\n\x08channels\x18\x01 \x03(\x0b2&.ibc.core.channel.v1.IdentifiedChannelB\x19\xfa\xde\x1f\x11IdentifiedChannel\xc8\xde\x1f\x00\x12@\n\x10acknowledgements\x18\x02 \x03(\x0b2 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00\x12;\n\x0bcommitments\x18\x03 \x03(\x0b2 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00\x128\n\x08receipts\x18\x04 \x03(\x0b2 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00\x12Z\n\x0esend_sequences\x18\x05 \x03(\x0b2#.ibc.core.channel.v1.PacketSequenceB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"send_sequences"\x12Z\n\x0erecv_sequences\x18\x06 \x03(\x0b2#.ibc.core.channel.v1.PacketSequenceB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"recv_sequences"\x12X\n\rack_sequences\x18\x07 \x03(\x0b2#.ibc.core.channel.v1.PacketSequenceB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"ack_sequences"\x12?\n\x15next_channel_sequence\x18\x08 \x01(\x04B \xf2\xde\x1f\x1cyaml:"next_channel_sequence""r\n\x0ePacketSequence\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12\x10\n\x08sequence\x18\x03 \x01(\x04B;Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/types'
    _GENESISSTATE.fields_by_name['channels']._options = None
    _GENESISSTATE.fields_by_name['channels']._serialized_options = b'\xfa\xde\x1f\x11IdentifiedChannel\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['acknowledgements']._options = None
    _GENESISSTATE.fields_by_name['acknowledgements']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['commitments']._options = None
    _GENESISSTATE.fields_by_name['commitments']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['receipts']._options = None
    _GENESISSTATE.fields_by_name['receipts']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['send_sequences']._options = None
    _GENESISSTATE.fields_by_name['send_sequences']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"send_sequences"'
    _GENESISSTATE.fields_by_name['recv_sequences']._options = None
    _GENESISSTATE.fields_by_name['recv_sequences']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:"recv_sequences"'
    _GENESISSTATE.fields_by_name['ack_sequences']._options = None
    _GENESISSTATE.fields_by_name['ack_sequences']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"ack_sequences"'
    _GENESISSTATE.fields_by_name['next_channel_sequence']._options = None
    _GENESISSTATE.fields_by_name['next_channel_sequence']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"next_channel_sequence"'
    _PACKETSEQUENCE.fields_by_name['port_id']._options = None
    _PACKETSEQUENCE.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _PACKETSEQUENCE.fields_by_name['channel_id']._options = None
    _PACKETSEQUENCE.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _GENESISSTATE._serialized_start = 116
    _GENESISSTATE._serialized_end = 739
    _PACKETSEQUENCE._serialized_start = 741
    _PACKETSEQUENCE._serialized_end = 855




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b"\n\x1esentinel/types/v1/status.proto\x12\x11sentinel.types.v1\x1a\x14gogoproto/gogo.proto*\xbd\x01\n\x06Status\x12-\n\x12STATUS_UNSPECIFIED\x10\x00\x1a\x15\x8a\x9d \x11StatusUnspecified\x12#\n\rSTATUS_ACTIVE\x10\x01\x1a\x10\x8a\x9d \x0cStatusActive\x126\n\x17STATUS_INACTIVE_PENDING\x10\x02\x1a\x19\x8a\x9d \x15StatusInactivePending\x12'\n\x0fSTATUS_INACTIVE\x10\x03\x1a\x12\x8a\x9d \x0eStatusInactiveB4Z&github.com/sentinel-official/hub/types\xc8\xe1\x1e\x00\xd0\xe1\x1e\x00\xe8\xe2\x1e\x00b\x06proto3")
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.types.v1.status_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z&github.com/sentinel-official/hub/types\xc8\xe1\x1e\x00\xd0\xe1\x1e\x00\xe8\xe2\x1e\x00'
    _STATUS.values_by_name['STATUS_UNSPECIFIED']._options = None
    _STATUS.values_by_name['STATUS_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x11StatusUnspecified'
    _STATUS.values_by_name['STATUS_ACTIVE']._options = None
    _STATUS.values_by_name['STATUS_ACTIVE']._serialized_options = b'\x8a\x9d \x0cStatusActive'
    _STATUS.values_by_name['STATUS_INACTIVE_PENDING']._options = None
    _STATUS.values_by_name['STATUS_INACTIVE_PENDING']._serialized_options = b'\x8a\x9d \x15StatusInactivePending'
    _STATUS.values_by_name['STATUS_INACTIVE']._options = None
    _STATUS.values_by_name['STATUS_INACTIVE']._serialized_options = b'\x8a\x9d \x0eStatusInactive'
    _STATUS._serialized_start = 76
    _STATUS._serialized_end = 265




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/crypto/ed25519/keys.proto\x12\x15cosmos.crypto.ed25519\x1a\x14gogoproto/gogo.proto"9\n\x06PubKey\x12)\n\x03key\x18\x01 \x01(\x0cB\x1c\xfa\xde\x1f\x18crypto/ed25519.PublicKey:\x04\x98\xa0\x1f\x00"5\n\x07PrivKey\x12*\n\x03key\x18\x01 \x01(\x0cB\x1d\xfa\xde\x1f\x19crypto/ed25519.PrivateKeyB2Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.ed25519.keys_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519'
    _PUBKEY.fields_by_name['key']._options = None
    _PUBKEY.fields_by_name['key']._serialized_options = b'\xfa\xde\x1f\x18crypto/ed25519.PublicKey'
    _PUBKEY._options = None
    _PUBKEY._serialized_options = b'\x98\xa0\x1f\x00'
    _PRIVKEY.fields_by_name['key']._options = None
    _PRIVKEY.fields_by_name['key']._serialized_options = b'\xfa\xde\x1f\x19crypto/ed25519.PrivateKey'
    _PUBKEY._serialized_start = 81
    _PUBKEY._serialized_end = 138
    _PRIVKEY._serialized_start = 140
    _PRIVKEY._serialized_end = 193




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/privval/types.proto\x12\x12tendermint.privval\x1a\x1ctendermint/crypto/keys.proto\x1a\x1ctendermint/types/types.proto\x1a\x14gogoproto/gogo.proto"6\n\x11RemoteSignerError\x12\x0c\n\x04code\x18\x01 \x01(\x05\x12\x13\n\x0bdescription\x18\x02 \x01(\t"!\n\rPubKeyRequest\x12\x10\n\x08chain_id\x18\x01 \x01(\t"{\n\x0ePubKeyResponse\x123\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x124\n\x05error\x18\x02 \x01(\x0b2%.tendermint.privval.RemoteSignerError"I\n\x0fSignVoteRequest\x12$\n\x04vote\x18\x01 \x01(\x0b2\x16.tendermint.types.Vote\x12\x10\n\x08chain_id\x18\x02 \x01(\t"v\n\x12SignedVoteResponse\x12*\n\x04vote\x18\x01 \x01(\x0b2\x16.tendermint.types.VoteB\x04\xc8\xde\x1f\x00\x124\n\x05error\x18\x02 \x01(\x0b2%.tendermint.privval.RemoteSignerError"U\n\x13SignProposalRequest\x12,\n\x08proposal\x18\x01 \x01(\x0b2\x1a.tendermint.types.Proposal\x12\x10\n\x08chain_id\x18\x02 \x01(\t"\x82\x01\n\x16SignedProposalResponse\x122\n\x08proposal\x18\x01 \x01(\x0b2\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\x124\n\x05error\x18\x02 \x01(\x0b2%.tendermint.privval.RemoteSignerError"\r\n\x0bPingRequest"\x0e\n\x0cPingResponse"\xa6\x04\n\x07Message\x12<\n\x0fpub_key_request\x18\x01 \x01(\x0b2!.tendermint.privval.PubKeyRequestH\x00\x12>\n\x10pub_key_response\x18\x02 \x01(\x0b2".tendermint.privval.PubKeyResponseH\x00\x12@\n\x11sign_vote_request\x18\x03 \x01(\x0b2#.tendermint.privval.SignVoteRequestH\x00\x12F\n\x14signed_vote_response\x18\x04 \x01(\x0b2&.tendermint.privval.SignedVoteResponseH\x00\x12H\n\x15sign_proposal_request\x18\x05 \x01(\x0b2\'.tendermint.privval.SignProposalRequestH\x00\x12N\n\x18signed_proposal_response\x18\x06 \x01(\x0b2*.tendermint.privval.SignedProposalResponseH\x00\x127\n\x0cping_request\x18\x07 \x01(\x0b2\x1f.tendermint.privval.PingRequestH\x00\x129\n\rping_response\x18\x08 \x01(\x0b2 .tendermint.privval.PingResponseH\x00B\x05\n\x03sum*\xa8\x01\n\x06Errors\x12\x12\n\x0eERRORS_UNKNOWN\x10\x00\x12\x1e\n\x1aERRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14ERRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19ERRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13ERRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14ERRORS_WRITE_TIMEOUT\x10\x05B;Z9github.com/tendermint/tendermint/proto/tendermint/privvalb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.privval.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/privval'
    _PUBKEYRESPONSE.fields_by_name['pub_key']._options = None
    _PUBKEYRESPONSE.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _SIGNEDVOTERESPONSE.fields_by_name['vote']._options = None
    _SIGNEDVOTERESPONSE.fields_by_name['vote']._serialized_options = b'\xc8\xde\x1f\x00'
    _SIGNEDPROPOSALRESPONSE.fields_by_name['proposal']._options = None
    _SIGNEDPROPOSALRESPONSE.fields_by_name['proposal']._serialized_options = b'\xc8\xde\x1f\x00'
    _ERRORS._serialized_start = 1352
    _ERRORS._serialized_end = 1520
    _REMOTESIGNERERROR._serialized_start = 136
    _REMOTESIGNERERROR._serialized_end = 190
    _PUBKEYREQUEST._serialized_start = 192
    _PUBKEYREQUEST._serialized_end = 225
    _PUBKEYRESPONSE._serialized_start = 227
    _PUBKEYRESPONSE._serialized_end = 350
    _SIGNVOTEREQUEST._serialized_start = 352
    _SIGNVOTEREQUEST._serialized_end = 425
    _SIGNEDVOTERESPONSE._serialized_start = 427
    _SIGNEDVOTERESPONSE._serialized_end = 545
    _SIGNPROPOSALREQUEST._serialized_start = 547
    _SIGNPROPOSALREQUEST._serialized_end = 632
    _SIGNEDPROPOSALRESPONSE._serialized_start = 635
    _SIGNEDPROPOSALRESPONSE._serialized_end = 765
    _PINGREQUEST._serialized_start = 767
    _PINGREQUEST._serialized_end = 780
    _PINGRESPONSE._serialized_start = 782
    _PINGRESPONSE._serialized_end = 796
    _MESSAGE._serialized_start = 799
    _MESSAGE._serialized_end = 1349




from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as _abci_pb2
from cosmos.authz.v1beta1 import authz_pb2 as _authz_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgExec(_message.Message):
    __slots__ = ['grantee', 'msgs']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    MSGS_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    msgs: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, grantee: _Optional[str]=..., msgs: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=...) -> None:
        ...

class MsgExecResponse(_message.Message):
    __slots__ = ['results']
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, results: _Optional[_Iterable[bytes]]=...) -> None:
        ...

class MsgGrant(_message.Message):
    __slots__ = ['grant', 'grantee', 'granter']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANT_FIELD_NUMBER: _ClassVar[int]
    grant: _authz_pb2.Grant
    grantee: str
    granter: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=..., grant: _Optional[_Union[(_authz_pb2.Grant, _Mapping)]]=...) -> None:
        ...

class MsgGrantResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgRevoke(_message.Message):
    __slots__ = ['grantee', 'granter', 'msg_type_url']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str
    msg_type_url: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=..., msg_type_url: _Optional[str]=...) -> None:
        ...

class MsgRevokeResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.distribution.v1beta1 import query_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service for distribution module.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Params = channel.unary_unary('/cosmos.distribution.v1beta1.Query/Params', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString)
        self.ValidatorOutstandingRewards = channel.unary_unary('/cosmos.distribution.v1beta1.Query/ValidatorOutstandingRewards', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.FromString)
        self.ValidatorCommission = channel.unary_unary('/cosmos.distribution.v1beta1.Query/ValidatorCommission', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.FromString)
        self.ValidatorSlashes = channel.unary_unary('/cosmos.distribution.v1beta1.Query/ValidatorSlashes', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.FromString)
        self.DelegationRewards = channel.unary_unary('/cosmos.distribution.v1beta1.Query/DelegationRewards', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.FromString)
        self.DelegationTotalRewards = channel.unary_unary('/cosmos.distribution.v1beta1.Query/DelegationTotalRewards', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.FromString)
        self.DelegatorValidators = channel.unary_unary('/cosmos.distribution.v1beta1.Query/DelegatorValidators', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString)
        self.DelegatorWithdrawAddress = channel.unary_unary('/cosmos.distribution.v1beta1.Query/DelegatorWithdrawAddress', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.FromString)
        self.CommunityPool = channel.unary_unary('/cosmos.distribution.v1beta1.Query/CommunityPool', request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.SerializeToString, response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service for distribution module.\n    '

    def Params(self, request, context):
        'Params queries params of the distribution module.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorOutstandingRewards(self, request, context):
        'ValidatorOutstandingRewards queries rewards of a validator address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorCommission(self, request, context):
        'ValidatorCommission queries accumulated commission for a validator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorSlashes(self, request, context):
        'ValidatorSlashes queries slash events of a validator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegationRewards(self, request, context):
        'DelegationRewards queries the total rewards accrued by a delegation.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegationTotalRewards(self, request, context):
        'DelegationTotalRewards queries the total rewards accrued by a each\n        validator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidators(self, request, context):
        'DelegatorValidators queries the validators of a delegator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorWithdrawAddress(self, request, context):
        'DelegatorWithdrawAddress queries withdraw address of a delegator.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommunityPool(self, request, context):
        'CommunityPool queries the community pool coins.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString), 'ValidatorOutstandingRewards': grpc.unary_unary_rpc_method_handler(servicer.ValidatorOutstandingRewards, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.SerializeToString), 'ValidatorCommission': grpc.unary_unary_rpc_method_handler(servicer.ValidatorCommission, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.SerializeToString), 'ValidatorSlashes': grpc.unary_unary_rpc_method_handler(servicer.ValidatorSlashes, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.SerializeToString), 'DelegationRewards': grpc.unary_unary_rpc_method_handler(servicer.DelegationRewards, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.SerializeToString), 'DelegationTotalRewards': grpc.unary_unary_rpc_method_handler(servicer.DelegationTotalRewards, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.SerializeToString), 'DelegatorValidators': grpc.unary_unary_rpc_method_handler(servicer.DelegatorValidators, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.SerializeToString), 'DelegatorWithdrawAddress': grpc.unary_unary_rpc_method_handler(servicer.DelegatorWithdrawAddress, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.SerializeToString), 'CommunityPool': grpc.unary_unary_rpc_method_handler(servicer.CommunityPool, request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.FromString, response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.distribution.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service for distribution module.\n    '

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/Params', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorOutstandingRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorOutstandingRewards', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorCommission(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorCommission', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorSlashes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorSlashes', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegationRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegationRewards', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegationTotalRewards(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegationTotalRewards', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorValidators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegatorValidators', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorWithdrawAddress(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegatorWithdrawAddress', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommunityPool(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/CommunityPool', cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.SerializeToString, cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
